<?php
/**
 * ogee functions and definitions
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 * @package ogee
 */

/* Enqueue scripts and styles.*/
function ogee_css_include() {
	
    wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/assets/fontawesome/css/font-awesome.css' );
    wp_enqueue_style( 'flexslider', get_template_directory_uri().'/assets/flexslider/css/flexslider.css' );

    wp_enqueue_style( 'ogee-style', get_stylesheet_uri());

    wp_register_script( 'flexslider-min', get_template_directory_uri(). '/assets/flexslider/js/jquery.flexslider.js',array('jquery'), null, true );

    wp_enqueue_script('ogee-header', get_template_directory_uri(). '/inc/js/main-nav.js', array( 'jquery', 'masonry', 'flexslider-min' ), '1.0.0', true);


    wp_enqueue_script( 'masonry' ,array('jquery') );
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
    }

    wp_enqueue_style( 'ogee-fonts', ogee_fonts_url(), array(), null );

}
add_action('wp_enqueue_scripts', 'ogee_css_include');


function ogee_customizer_include() {
    wp_enqueue_script('ogee-customizer', get_template_directory_uri(). '/inc/js/customizer.js',array( 'customize-preview' ), '1.0.0', true);
}
add_action('customize_preview_init', 'ogee_customizer_include');


function ogee_theme_steup() {
    // Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );
    
    /*
    * Let WordPress manage the document title.
    * By adding theme support, we declare that this theme does not use a
    * hard-coded <title> tag in the document head, and expect WordPress to
    * provide it for us.
    */
    add_theme_support( 'title-tag' );

    /*
    * Enable support for Post Thumbnails on posts and pages.
    *
    * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
    */
    add_theme_support( 'post-thumbnails', array( 'post', 'page' ) );

    // This theme uses wp_nav_menu() in one location.
    register_nav_menus( array(
        'primary' => esc_html__( 'Primary Menu', 'ogee' ),
        'footer' => esc_html__( 'Footer Menu', 'ogee' ),
    ) );

    /*
    * Switch default core markup for search form, comment form, and comments
    * to output valid HTML5.
    */
    add_theme_support( 'html5', array(
        'comment-form',
        'comment-list',
        'gallery',
        'caption',
    ) );

    /*
    * Enable support for Post Formats.
    * See http://codex.wordpress.org/Post_Formats
    */
    add_theme_support( 'post-formats', array(
        'aside',
        'quote',
    ) );

    // Set up the WordPress core custom background feature.
    add_theme_support( 'custom-background', apply_filters( 'ogee_custom_background_args', array(
    'default-color' => 'e2e2e2',
    'default-image' => '',
    ) ) );

    //Custom header support feature.
    $args = array(
        'width'         => 1200,
        'height'        => 250,
    );
    add_theme_support( 'custom-header', $args );

    //Adding the Editor style css
    add_editor_style( 'inc/css/editor-style.css' );
    add_editor_style( array( 'inc/css/editor-style.css', ogee_fonts_url() ) );


    //Register custom image size
    add_image_size('ogee-slider-thumbnail', 768, 400, true);

    //Registration of Widget
    register_widget( 'ogee_popular_posts' );
    register_widget( 'Ogee_social_media_links' ); 

}
add_action( 'after_setup_theme', 'ogee_theme_steup' );


/** Registering the Sidebar widget
 *
 */

function ogee_initialize_widget() {
	
	//right sidebar register
	
	register_sidebar( array(
		
		'name' 				=> esc_html__('Right Sidebar', 'ogee'),
		'id' 				=> 'sidebar-1',
		'description'   	=> __('This is the main sidebar of the website. Which will appear on the right side of the page.','ogee'),
		'before_widget'     => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'      => '</aside>',
		'before_title'      => '<h1 class="widget-title">',
		'after_title'       => '</h1>',
		
	));
	
	
}   

add_action('widgets_init', 'ogee_initialize_widget');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function ogee_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'ogee_content_width', 900 );
}
add_action( 'after_setup_theme', 'ogee_content_width', 0 );

require get_template_directory() . '/inc/customizer.php';
require get_template_directory() . '/inc/template-tag.php';


if ( ! function_exists( 'ogee_fonts_url' ) ) :
    /**
     * Register Google fonts for Ogee
     *
     * @return string Google fonts URL for the theme.
     */
    function ogee_fonts_url() {
        $fonts_url = '';
        $fonts     = array();
        
    
        $fonts[] = 'Noto Sans:400,400italic,700,700italic';
        $fonts[] = 'Cousine:400';
        
            $fonts_url = add_query_arg( array(
                'family' =>  implode('|', $fonts ),
            ), 'https://fonts.googleapis.com/css' );
        
    
        return $fonts_url;
    }
endif;

/**
 * Ogee load widget files
 */
require get_template_directory() . '/inc/widgets/popular-posts.php';
require get_template_directory() . '/inc/widgets/social-links.php';