<?php
/**
 * ogee Theme Customizer
 *
 * @package ogee
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function ogee_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
    $wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	

	// Add new panel for all theme settings
	$wp_customize->add_panel('ogee_theme_options', array(
        'capability' => 'edit_theme_options',
        'theme_supports' => '',
        'title' => __('Ogee theme options', 'ogee'),
        'description' => __('Panel to update ogee theme options', 'ogee'), 
        'priority' => 60
	));

		// Register general theme feature section
		$wp_customize->add_section('ogee_general_features', array(
			'title' 	=> __('General theme options', 'ogee'),
			'priority'	=> 60,
			'panel'		=> 'ogee_theme_options',
		));

			//Enable Author Infobox on Single Post
			$wp_customize->add_setting( 'author_box', array(
				'default'      	    => 0,
				'transport' 		=> 'refresh',
				'sanitize_callback' => 'ogee_sanitize_checkbox',
			) );

			$wp_customize->add_control( 'author_box', array(
					'label'     => __( 'Display Author Infobox?', 'ogee' ),
					'section'   => 'ogee_general_features',
					'type'      => 'checkbox',
					'settings'  => 'author_box',
			) );

			//Enable Related posts on Single Post
			$wp_customize->add_setting( 'related_posts', array(
				'default'      	    => 0,
				'transport' 		=> 'refresh',
				'sanitize_callback' => 'ogee_sanitize_checkbox',
			) );

			$wp_customize->add_control( 'related_posts', array(
					'label'     => __( 'Display Related posts?', 'ogee' ),
					'section'   => 'ogee_general_features',
					'type'      => 'checkbox',
					'settings'  => 'related_posts',
			) );

			//Enable Scroll top
			$wp_customize->add_setting( 'scroll_top', array(
				'default'      	    => 1,
				'transport' 		=> 'refresh',
				'sanitize_callback' => 'ogee_sanitize_checkbox',
			) );

			$wp_customize->add_control( 'scroll_top', array(
					'label'     => __( 'Enable Scroll to top?', 'ogee' ),
					'section'   => 'ogee_general_features',
					'type'      => 'checkbox',
					'settings'  => 'scroll_top',
			) );


			//Featured image on post page
			$wp_customize->add_setting( 'featurd_img_post', array(
				'default'      	    => 0,
				'transport' 		=> 'refresh',
				'sanitize_callback' => 'ogee_sanitize_checkbox',
			) );

			$wp_customize->add_control( 'featurd_img_post', array(
					'label'     => __( 'Display featured image on post page?', 'ogee' ),
					'section'   => 'ogee_general_features',
					'type'      => 'checkbox',
					'settings'  => 'featurd_img_post',
			) );

		
		
		
		// Register advance theme feature section
		$wp_customize->add_section('ogee_advance_features', array(
			'title' 	=> __('Content options', 'ogee'),
			'priority'	=> 60,
			'panel'		=> 'ogee_theme_options',
		));

			

			//Featured image on post page
			$wp_customize->add_setting( 'featured_section_homepage', array(
				'default'      	    => 0,
				'transport' 		=> 'refresh',
				'sanitize_callback' => 'ogee_sanitize_checkbox',
			) );

			$wp_customize->add_control( 'featured_section_homepage', array(
				'label'     => __( 'Display featured section on home page?', 'ogee' ),
				'section'   => 'ogee_advance_features',
				'type'      => 'checkbox',
				'settings'  => 'featured_section_homepage',
				'priority' 	=> 1
			) );
				

			//now a dropdown menu to let user choose category for the featured section on home page

			$wp_customize->add_setting( 'ogee_fetch_category', array(
				'default'       	=> '0',
				'transport'			=> 'refresh',
				'sanitize_callback' => 'absint',
				
			) );

			$categories = get_categories();
			$output = array();
			
			foreach ( $categories as $category ) { 
				$output[$category->term_id] = $category->name;
			}

			$wp_customize->add_control( 'ogee_fetch_category', array(
				'description' 	=> __( 'Select category', 'ogee' ),
				'section' 		=> 'ogee_advance_features',
				'type'    		=> 'select',
				'choices' 		=> $output,
				'priority' 		=> 4
			) );

}
add_action( 'customize_register', 'ogee_customize_register' );


//Control / Sanitize all Checkbox values
function ogee_sanitize_checkbox( $input ) {
    // Boolean check
	return ( ( isset( $input ) && true == $input ) ? true : false );
	
}


function ogee_sanitize_select( $input, $setting ) {

  
	$input = sanitize_key( $input );
  
	$choices = $setting->manager->get_control( $setting->id )->choices;
  
	//returns actual value
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}





function ogee_featured_section(){
	
	// WP_Query arguments
	$args = array(
		'category__in' => absint( get_theme_mod( "ogee_fetch_category") ),
		'posts_per_page'=> 5,
		'meta_query' => array(
				array( 'key' => '_thumbnail_id'),
		)
	);

	// The Query
	$query = new WP_Query( $args );

	echo "<div class='main-featured-wrap'>";

	// The Loop
	if ( $query->have_posts() ) {?>
	<article class="slider-wrap">

	<div class="flexslider">
  <ul class="slides">
		<?php while ( $query->have_posts() ) {
			$query->the_post(); ?>
			

    <li>
		<a href="<?php the_permalink(); ?>">
		
				<?php the_post_thumbnail('ogee-slider-thumbnail'); ?>
		
		</a>
	  
	  <div class="flex-caption"><a href="<?php the_permalink(); ?>"><h3><?php the_title(); ?></h3></a></div>
    </li>
  
			
		<?php } ?>
		</ul>
	</div>
		</article>
		<?php } else {
		// no posts found
	}

	// Restore original Post Data
	wp_reset_postdata();

	echo "</div>";
}

